#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 one-liner
version:              2.1.1
visibility:           public
id:                   one-liner-2.1.1-JEAMkhVtqtMJceccEe2Xs9
key:                  one-liner-2.1.1-JEAMkhVtqtMJceccEe2Xs9
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher, Xia Li-yao
homepage:             https://github.com/sjoerdvisscher/one-liner
synopsis:             Constraint-based generics
description:
    Write short and concise generic instances of type classes.
    one-liner is particularly useful for writing default
    implementations of type class methods.

category:             Generics
abi:                  247c58557b79c987559e9ec47acdf668
exposed:              True
exposed-modules:
    Generics.OneLiner Generics.OneLiner.Binary
    Generics.OneLiner.Classes Generics.OneLiner.Internal
    Generics.OneLiner.Internal.Unary

import-dirs:          /usr/lib/ghc-9.6.6/site-local/one-liner-2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/one-liner-2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/one-liner-2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-one-liner
hs-libraries:         HSone-liner-2.1.1-JEAMkhVtqtMJceccEe2Xs9
depends:
    base-4.18.2.1 bifunctors-5.6.3-JxqVPFA87CgGZDQtN7CDR0
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg ghc-prim-0.10.0
    linear-base-0.7.0-1ac5exMb8c9ol7JyD8RYm
    profunctors-5.6.3-6xnRR8Hc4jMAg82vUDmFP0
    tagged-0.8.10-9VJfLOM9ch68xR35ePL46j

haddock-interfaces:   /usr/share/doc/haskell-one-liner/html/one-liner.haddock
haddock-html:         /usr/share/doc/haskell-one-liner/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

